@@ -3,24 +3,24 @@ eegica <-
            type=c("time","space"),method=c("imax","fast","jade"),...){
     ###### Independent Component Analysis for EEG data
     ###### Nathaniel E. Helwig (helwig@umn.edu)
-    ###### Last modified: September 5, 2014
+    ###### Last modified: February 16, 2015
     
     ### initial checks
-    X=as.matrix(X)
-    type=type[1]
+    X <- as.matrix(X)
+    type <- type[1]
     if(any(type==c("time","space"))==FALSE){stop("Input 'type' must be 'time' or 'space'.")}
-    if(type=="time"){X=t(X)}
-    method=method[1]
-    if(any(method==c("imax","fast","jade"))==FALSE){stop("Input 'method' must be 'imax', 'fast', or 'jade'.")}
+    if(type=="time"){X <- t(X)}
+    method <- method[1]
+    if(!any(method==c("imax","fast","jade"))){stop("Input 'method' must be 'imax', 'fast', or 'jade'.")}
     
     ### call ica algorithm
     if(method=="imax"){
-      imod=icaimax(X,nc,center,maxit,tol,Rmat,...)
+      imod <- icaimax(X,nc,center,maxit,tol,Rmat,...)
     } else if(method=="fast"){
-      imod=icafast(X,nc,center,maxit,tol,Rmat,...)
+      imod <- icafast(X,nc,center,maxit,tol,Rmat,...)
     } else {
-      imod=icajade(X,nc,center,maxit,tol,Rmat)
+      imod <- icajade(X,nc,center,maxit,tol,Rmat)
     }
-    return(imod=c(imod,type=type,method=method))
+    return(imod <- c(imod,type=type,method=method))
     
   }
\ No newline at end of file
